package com.example.aeropuertoback.entity;

import com.fasterxml.jackson.annotation.JsonProperty;
import org.springframework.format.annotation.DateTimeFormat;
import javax.persistence.*;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

@Entity
@Table(name="flight_schedules")
public class Vuelo {

    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    private Integer id;

    @Column(name="flight_cost")
    private double costo;

    @Column(name="airline_code")
    private String codigoAerolinea;

    @Column(name="usual_aircraft_type_code")
    private String codigoTipoAeronave;

    @Column(name="departure_date_time")
    @Temporal(TemporalType.TIMESTAMP)
    private Date fechaSalida;

    @Column(name="arrival_date_time")
    @Temporal(TemporalType.TIMESTAMP)
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    private Date fechaLlegada;

    @ManyToOne(fetch = FetchType.LAZY, optional = false)
    @JoinColumn(name = "origin_airport_code")
    @JsonProperty(access = JsonProperty.Access.WRITE_ONLY)
    private Aeropuerto codigoAeropuertoOrigen;

    @ManyToOne(fetch = FetchType.LAZY, optional = false)
    @JoinColumn(name = "destination_airport_code")
    @JsonProperty(access = JsonProperty.Access.WRITE_ONLY)
    private Aeropuerto codigoAeropuertoDestino;

    @OneToMany(mappedBy = "codigoVuelo", cascade = CascadeType.ALL)
    private List<Escala> escalas;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Vuelo(){
        escalas = new ArrayList<Escala>();
    }


    public Aeropuerto getCodigoAeropuertoOrigen() {
        return codigoAeropuertoOrigen;
    }

    public void setCodigoAeropuertoOrigen(Aeropuerto codigoAeropuertoOrigen) {
        this.codigoAeropuertoOrigen = codigoAeropuertoOrigen;
    }

    public Aeropuerto getCodigoAeropuertoDestino() {
        return codigoAeropuertoDestino;
    }

    public void setCodigoAeropuertoDestino(Aeropuerto codigoAeropuertoDestino) {
        this.codigoAeropuertoDestino = codigoAeropuertoDestino;
    }

    public List<Escala> getEscalas() {
        return escalas;
    }

    public void setEscalas(List<Escala> escalas) {
        this.escalas = escalas;
    }

    public Date getFechaSalida() {
        return fechaSalida;
    }

    public void setFechaSalida(Date fechaSalida) {
        this.fechaSalida = fechaSalida;
    }

    public Date getFechaLlegada() {
        return fechaLlegada;
    }

    public void setFechaLlegada(Date fechaLlegada) {
        this.fechaLlegada = fechaLlegada;
    }

    public String getAeropuertoOrigen(){
        return this.codigoAeropuertoOrigen.getCodigo();
    }

    public String getAeropuertoDestino(){
        return this.codigoAeropuertoDestino.getCodigo();
    }

    public double getCosto() {
        return costo;
    }

    public void setCosto(double costo) {
        this.costo = costo;
    }

    public String getCodigoAerolinea() {
        return codigoAerolinea;
    }

    public void setCodigoAerolinea(String codigoAerolinea) {
        this.codigoAerolinea = codigoAerolinea;
    }

    public String getCodigoTipoAeronave() {
        return codigoTipoAeronave;
    }

    public void setCodigoTipoAeronave(String codigoTipoAeronave) {
        this.codigoTipoAeronave = codigoTipoAeronave;
    }

    public Integer getCodigoOrigen(){
        return this.codigoAeropuertoOrigen.getId();
    }

    public Integer getCodigoDestino(){
        return this.codigoAeropuertoDestino.getId();
    }
}


